#! /usr/bin/python3

###########################################
# Demo - GPS TCP/IP Logger                #
###########################################
import Modem
import CommandQueue
import time
from Debug import debug, debug_header

###########################
# Configurable Parameters #
###########################
apn = "zap.vivo.com.br"
username = "vivo"
password = "vivo"
server_ip = "191.181.213.64"
server_port = 5150
gps_data = ""

def callback_modem(data):
    global Q
    debug("Modem >>",data,'green')
    Q.response(data)

def callback_gps(data):
    global QG , gps_data 
    if data.startswith("+QGPSLOC"):
      gps_data = data
    debug ("GPS >>",data,'yellow')
    QG.response(data)

def PrepareModem():
    global M,Q
    M = Modem.QuectelBG96(callback_modem,callback_gps)
    M.start()

    # CREATE THE MODEM COMMAND QUEUE (Q)
    Q = CommandQueue.Queue(M.modem_cmd)
    # ACTIVATE A PDP CONTEXT (QUEUE 0)
    Q.title(0,"Activate Context")
    Q.add(0,"ATE0","OK")
    Q.add(0,"AT+QICSGP=1,1,\"" + apn + "\",\"" + username + "\",\"" + password + "\"","OK")
    Q.add(0,"AT+QIDEACT=1","OK")
    Q.add(0,"AT+QIACT=1","OK")
    # OPEN A SOCKET SERVICE (QUEUE 1)
    Q.title(1,"Open a Socket")
    Q.add(1,"AT+QIOPEN=1,0,\"TCP\",\"" + server_ip + "\"," + str(server_port),"+QIOPEN:")
    # SEND DATA (QUEUE 2)
    Q.title(2,"Send Data")
    Q.add(2,"AT+QISEND=0",">")
    # CLOSE A SOCKET SERVICE (QUEUE 3)
    Q.title(3,"Close the Socket")
    Q.add(3,"AT+QICLOSE=0","OK")

def ActivateContext():
    global Q
    Q.trigger(0)              # activate context
    r = Q.waitCompletion(0)

def SendData(data):
    Q.trigger(1)              # open a socket  
    r = Q.waitCompletion(1)

    Q.sendData(2,data)        # send data  
    r = Q.waitCompletion(2)

    Q.trigger(3)              # close the socket
    r = Q.waitCompletion(3)

def PrepareGPS():
    global QG,M

    # CREATE THE GPS COMMAND QUEUE (QG)
    QG = CommandQueue.Queue(M.gps_cmd)
    # ENABLE GPS (QUEUE 0)
    QG.title(0,"Enable GPS")
    QG.add(0,"ate0","OK")
    QG.add(0,"at+qgps=1","OK")
    # GET GPS DATA (QUEUE 1)
    QG.title(1,"Get GPS Data")
    QG.add(1,"at+qgpsloc?","OK")

    QG.trigger(0)
    QG.waitCompletion(0)

def GetGPSData():
    global QG, gps_data
    QG.trigger(1)             # get gps data
    r = QG.waitCompletion(1)
    return gps_data

if __name__ == "__main__":
    ################
    # Setup        #
    ################
    PrepareModem()
    PrepareGPS()
    ActivateContext()

    #################
    # Infinite Loop #
    #################
    while True:
        SendData(GetGPSData())
        time.sleep(10)

    M.close()

